=======
History
=======

0.5.0 (2016-08-10)
------------------

* add grok filters for logstash
* slight adjustment to logfmt serialisation: talisker now strips " from tag
  values. This is due to a limitation in logstash.

0.4.1 (2016-08-05)
------------------

* publish separate py2/py3 wheels, due to dependency differences
* some doc changes

0.4.0 (2016-08-05)
------------------

* First public release an PyPI.
